@@ -21,12 +21,6 @@
 
 QT_BEGIN_NAMESPACE
 
-//both constants are taken from the default settings of Apache
-//see: http://httpd.apache.org/docs/2.2/mod/core.html#limitrequestfieldsize and
-//http://httpd.apache.org/docs/2.2/mod/core.html#limitrequestfields
-const int MAX_HEADERLINE_LENGTH = 8 * 1024; //maximum length of a http request header line
-const int MAX_HEADERLINES = 100;            //maximum number of http request header lines
-
 /*!
     \internal
  */
@@ -49,6 +43,11 @@ QWebSocketServerPrivate::QWebSocketServerPrivate(const QString &serverName,
 void QWebSocketServerPrivate::init()
 {
     Q_Q(QWebSocketServer);
+
+#ifdef Q_OS_WASM
+    qWarning("QWebSocketServer: WebSocket servers are not supported by Qt for WebAssembly");
+#endif
+
     if (m_secureMode == NonSecureMode) {
         m_pTcpServer = new QTcpServer(q);
         if (Q_LIKELY(m_pTcpServer))
@@ -66,35 +65,35 @@ void QWebSocketServerPrivate::init()
             QObjectPrivate::connect(pSslServer, &QTcpServer::pendingConnectionAvailable, this,
                                     &QWebSocketServerPrivate::onNewConnection,
                                     Qt::QueuedConnection);
-            QObject::connect(pSslServer, &QSslServer::peerVerifyError,
+            QObject::connect(pSslServer, &QSslServer::peerVerifyError, q,
                              [q](QSslSocket *socket, const QSslError &error) {
                                     Q_UNUSED(socket);
                                     Q_EMIT q->peerVerifyError(error);
                              });
-            QObject::connect(pSslServer, &QSslServer::sslErrors,
+            QObject::connect(pSslServer, &QSslServer::sslErrors, q,
                              [q](QSslSocket *socket, const QList<QSslError> &errors) {
                                     Q_UNUSED(socket);
                                     Q_EMIT q->sslErrors(errors);
                              });
-            QObject::connect(pSslServer, &QSslServer::preSharedKeyAuthenticationRequired,
+            QObject::connect(pSslServer, &QSslServer::preSharedKeyAuthenticationRequired, q,
                              [q](QSslSocket *socket,
                                  QSslPreSharedKeyAuthenticator *authenticator) {
                                     Q_UNUSED(socket);
                                     Q_EMIT q->preSharedKeyAuthenticationRequired(authenticator);
                              });
-            QObject::connect(pSslServer, &QSslServer::alertSent,
+            QObject::connect(pSslServer, &QSslServer::alertSent, q,
                              [q](QSslSocket *socket, QSsl::AlertLevel level,
                                  QSsl::AlertType type, const QString &description) {
                                     Q_UNUSED(socket);
                                     Q_EMIT q->alertSent(level, type, description);
                                  });
-            QObject::connect(pSslServer, &QSslServer::alertReceived,
+            QObject::connect(pSslServer, &QSslServer::alertReceived, q,
                              [q](QSslSocket *socket, QSsl::AlertLevel level,
                                  QSsl::AlertType type, const QString &description) {
                                     Q_UNUSED(socket);
                                     Q_EMIT q->alertReceived(level, type, description);
                                  });
-            QObject::connect(pSslServer, &QSslServer::handshakeInterruptedOnError,
+            QObject::connect(pSslServer, &QSslServer::handshakeInterruptedOnError, q,
                              [q](QSslSocket *socket, const QSslError &error) {
                                     Q_UNUSED(socket);
                                     Q_EMIT q->handshakeInterruptedOnError(error);
@@ -455,7 +454,8 @@ void QWebSocketServerPrivate::handshakeReceived()
     if (endOfHeaderIndex < 0) {
         //then we don't have our header complete yet
         //check that no one is trying to exhaust our virtual memory
-        const qint64 maxHeaderLength = MAX_HEADERLINE_LENGTH * MAX_HEADERLINES + endOfHeaderMarker.size();
+        const qint64 maxHeaderLength = QWebSocketPrivate::MAX_HEADERLINE_LENGTH
+            * QWebSocketPrivate::MAX_HEADERLINES + endOfHeaderMarker.size();
         if (Q_UNLIKELY(byteAvailable > maxHeaderLength)) {
             pTcpSocket->close();
             setError(QWebSocketProtocol::CloseCodeTooMuchData,
@@ -490,7 +490,7 @@ void QWebSocketServerPrivate::handshakeReceived()
     }
 
     QWebSocketHandshakeRequest request(pTcpSocket->peerPort(), isSecure);
-    request.readHandshake(header, MAX_HEADERLINE_LENGTH);
+    request.readHandshake(header, QWebSocketPrivate::MAX_HEADERLINE_LENGTH);
 
     if (request.isValid()) {
         QWebSocketCorsAuthenticator corsAuthenticator(request.origin());
@@ -563,9 +563,7 @@ void QWebSocketServerPrivate::startHandshakeTimeout(QTcpSocket *pTcpSocket)
     QTimer *handshakeTimer = new QTimer(pTcpSocket);
     handshakeTimer->setSingleShot(true);
     handshakeTimer->setObjectName(QStringLiteral("handshakeTimer"));
-    QObject::connect(handshakeTimer, &QTimer::timeout, [=]() {
-        pTcpSocket->close();
-    });
+    QObject::connect(handshakeTimer, &QTimer::timeout, pTcpSocket, &QAbstractSocket::close);
     handshakeTimer->start(m_handshakeTimeout);
 }
 
